==> Zeta-1.0-30.61-sources.jar: org/violetmoon/zetaimplforge/client/event/play/ForgeZScreen.java <==
package org.violetmoon.zetaimplforge.client.event.play;

import net.minecraft.client.gui.GuiGraphics;
import net.minecraft.client.gui.components.events.GuiEventListener;
import net.minecraft.client.gui.screens.Screen;
import net.neoforged.neoforge.client.event.ScreenEvent;
import org.violetmoon.zeta.client.event.play.ZScreen;

import java.util.List;

public class ForgeZScreen implements ZScreen {
    public final ScreenEvent e;

    public ForgeZScreen(ScreenEvent e) {
        this.e = e;
    }

    @Override
    public Screen getScreen() {
        return e.getScreen();
    }

    public static class Init extends ForgeZScreen implements ZScreen.Init {
        private final ScreenEvent.Init e;

        public Init(ScreenEvent.Init e) {
            super(e);
            this.e = e;
        }

        @Override
        public List<GuiEventListener> getListenersList() {
            return e.getListenersList();
        }

        @Override
        public void addListener(GuiEventListener listener) {
            e.addListener(listener);
        }

        @Override
        public void removeListener(GuiEventListener listener) {
            e.removeListener(listener);
        }

        public static class Pre extends ForgeZScreen.Init implements ZScreen.Init.Pre {
            public Pre(ScreenEvent.Init.Pre e) {
                super(e);
            }
        }

        public static class Post extends ForgeZScreen.Init implements ZScreen.Init.Post {
            public Post(ScreenEvent.Init.Post e) {
                super(e);
            }
        }
    }

    public static class Render extends ForgeZScreen implements ZScreen.Render {
        public final ScreenEvent.Render e;

        public Render(ScreenEvent.Render e) {
            super(e);
            this.e = e;
        }

        @Override
        public GuiGraphics getGuiGraphics() {
            return e.getGuiGraphics();
        }

        @Override
        public int getMouseX() {
            return e.getMouseX();
        }

        @Override
        public int getMouseY() {
            return e.getMouseY();
        }

        public static class Pre extends ForgeZScreen.Render implements ZScreen.Render.Pre {
            public Pre(ScreenEvent.Render.Pre e) {
                super(e);
            }
        }

        public static class Post extends ForgeZScreen.Render implements ZScreen.Render.Post {
            public Post(ScreenEvent.Render.Post e) {
                super(e);
            }
        }
    }

    public static class MouseButtonPressed extends ForgeZScreen implements ZScreen.MouseButtonPressed {
        final ScreenEvent.MouseButtonPressed e;

        public MouseButtonPressed(ScreenEvent.MouseButtonPressed e) {
            super(e);
            this.e = e;
        }

        @Override
        public int getButton() {
            return e.getButton();
        }

        @Override
        public double getMouseX() {
            return e.getMouseX();
        }

        @Override
        public double getMouseY() {
            return e.getMouseY();
        }

        public static class Pre extends ForgeZScreen.MouseButtonPressed implements ZScreen.MouseButtonPressed.Pre {
            public Pre(ScreenEvent.MouseButtonPressed.Pre e) {
                super(e);
            }
            
            @Override
            public boolean isCanceled() {
                return ((ScreenEvent.MouseButtonPressed.Pre)e).isCanceled();
            }

            @Override
            public void setCanceled(boolean canceled) {
                ((ScreenEvent.MouseButtonPressed.Pre)e).setCanceled(canceled);
            }
        }

        public static class Post extends ForgeZScreen.MouseButtonPressed implements ZScreen.MouseButtonPressed.Post {
            public Post(ScreenEvent.MouseButtonPressed.Post e) {
                super(e);
            }
        }
    }

    public abstract static class MouseScrolled extends ForgeZScreen implements ZScreen.MouseScrolled {
        final ScreenEvent.MouseScrolled e;

        public MouseScrolled(ScreenEvent.MouseScrolled e) {
            super(e);
            this.e = e;
        }

        @Override
        public double getScrollDeltaX() {
            return e.getScrollDeltaX();
        }

        @Override
        public double getScrollDeltaY() {
            return e.getScrollDeltaY();
        }

        public static class Pre extends ForgeZScreen.MouseScrolled implements ZScreen.MouseScrolled.Pre {
            public Pre(ScreenEvent.MouseScrolled.Pre e) {
                super(e);
            }

            @Override
            public boolean isCanceled() {
                return ((ScreenEvent.MouseScrolled.Pre)e).isCanceled();
            }

            @Override
            public void setCanceled(boolean cancel) {
                ((ScreenEvent.MouseScrolled.Pre)e).setCanceled(cancel);
            }
        }

        public static class Post extends ForgeZScreen.MouseScrolled implements ZScreen.MouseScrolled.Post {
            public Post(ScreenEvent.MouseScrolled.Post e) {
                super(e);
            }

            @Override
            public boolean isCanceled() {
                return false;
            }

            @Override
            public void setCanceled(boolean cancel) {
                //NO OP
            }
        }
    }

    public static abstract class KeyPressed extends ForgeZScreen implements ZScreen.KeyPressed {
        final ScreenEvent.KeyPressed e;

        public KeyPressed(ScreenEvent.KeyPressed e) {
            super(e);
            this.e = e;
        }

        @Override
        public int getKeyCode() {
            return e.getKeyCode();
        }

        @Override
        public int getScanCode() {
            return e.getScanCode();
        }

        @Override
        public int getModifiers() {
            return e.getModifiers();
        }

        public static class Pre extends ForgeZScreen.KeyPressed implements ZScreen.KeyPressed.Pre {
            public Pre(ScreenEvent.KeyPressed.Pre e) {
                super(e);
            }

            @Override
            public boolean isCanceled() {
                return ((ScreenEvent.KeyPressed.Pre)e).isCanceled();
            }

            @Override
            public void setCanceled(boolean cancel) {
                ((ScreenEvent.KeyPressed.Pre)e).setCanceled(cancel);
            }
        }

        public static class Post extends ForgeZScreen.KeyPressed implements ZScreen.KeyPressed.Post {
            public Post(ScreenEvent.KeyPressed.Post e) {
                super(e);
            }

            @Override
            public boolean isCanceled() {
                return ((ScreenEvent.KeyPressed.Post)e).isCanceled();
            }

            @Override
            public void setCanceled(boolean cancel) {
                ((ScreenEvent.KeyPressed.Post)e).setCanceled(cancel);
            }
        }
    }

    public static abstract class CharacterTyped extends ForgeZScreen implements ZScreen.CharacterTyped {
        final ScreenEvent.CharacterTyped e;

        public CharacterTyped(ScreenEvent.CharacterTyped e) {
            super(e);
            this.e = e;
        }

        @Override
        public char getCodePoint() {
            return e.getCodePoint();
        }

        @Override
        public int getModifiers() {
            return e.getModifiers();
        }

        public static class Pre extends ForgeZScreen.CharacterTyped implements ZScreen.CharacterTyped.Pre {
            public Pre(ScreenEvent.CharacterTyped.Pre e) {
                super(e);
            }

            @Override
            public boolean isCanceled() {
                return ((ScreenEvent.CharacterTyped.Pre)e).isCanceled();
            }

            @Override
            public void setCanceled(boolean cancel) {
                ((ScreenEvent.CharacterTyped.Pre)e).setCanceled(cancel);
            }
        }

        public static class Post extends ForgeZScreen.CharacterTyped implements ZScreen.CharacterTyped.Post {
            public Post(ScreenEvent.CharacterTyped.Post e) {
                super(e);
            }

            @Override
            public boolean isCanceled() {
                return false;
            }

            @Override
            public void setCanceled(boolean cancel) {
                // NOTHING TO BE CANCELED
            }
        }
    }

    public static class Opening extends ForgeZScreen implements ZScreen.Opening {
        private final ScreenEvent.Opening e;

        public Opening(ScreenEvent.Opening e) {
            super(e);
            this.e = e;
        }

        @Override
        public Screen getCurrentScreen() {
            return e.getCurrentScreen();
        }

        @Override
        public Screen getNewScreen() {
            return e.getNewScreen();
        }

        @Override
        public void setNewScreen(Screen newScreen) {
            e.setNewScreen(newScreen);
        }

        @Override
        public boolean isCanceled() {
            return e.isCanceled();
        }

        @Override
        public void setCanceled(boolean cancel) {
            e.setCanceled(true);
        }
    }
}

==> Zeta-1.0-31.2-sources.jar: org/violetmoon/zetaimplforge/client/event/play/ForgeZScreen.java <==
package org.violetmoon.zetaimplforge.client.event.play;

import java.util.List;

import org.violetmoon.zeta.client.event.play.ZScreen;

import net.minecraft.client.gui.GuiGraphics;
import net.minecraft.client.gui.components.events.GuiEventListener;
import net.minecraft.client.gui.screens.Screen;
import net.minecraftforge.client.event.ScreenEvent;

public class ForgeZScreen implements ZScreen {
    public final ScreenEvent e;

    public ForgeZScreen(ScreenEvent e) {
        this.e = e;
    }

    @Override
    public Screen getScreen() {
        return e.getScreen();
    }

    public static class Init extends ForgeZScreen implements ZScreen.Init {
        private final ScreenEvent.Init e;

        public Init(ScreenEvent.Init e) {
            super(e);
            this.e = e;
        }

        @Override
        public List<GuiEventListener> getListenersList() {
            return e.getListenersList();
        }

        @Override
        public void addListener(GuiEventListener listener) {
            e.addListener(listener);
        }

        @Override
        public void removeListener(GuiEventListener listener) {
            e.removeListener(listener);
        }

        public static class Pre extends ForgeZScreen.Init implements ZScreen.Init.Pre {
            public Pre(ScreenEvent.Init.Pre e) {
                super(e);
            }
        }

        public static class Post extends ForgeZScreen.Init implements ZScreen.Init.Post {
            public Post(ScreenEvent.Init.Post e) {
                super(e);
            }
        }
    }

    public static class Render extends ForgeZScreen implements ZScreen.Render {
        public final ScreenEvent.Render e;

        public Render(ScreenEvent.Render e) {
            super(e);
            this.e = e;
        }

        @Override
        public GuiGraphics getGuiGraphics() {
            return e.getGuiGraphics();
        }

        @Override
        public int getMouseX() {
            return e.getMouseX();
        }

        @Override
        public int getMouseY() {
            return e.getMouseY();
        }

        public static class Pre extends ForgeZScreen.Render implements ZScreen.Render.Pre {
            public Pre(ScreenEvent.Render.Pre e) {
                super(e);
            }
        }

        public static class Post extends ForgeZScreen.Render implements ZScreen.Render.Post {
            public Post(ScreenEvent.Render.Post e) {
                super(e);
            }
        }
    }

    public static class MouseButtonPressed extends ForgeZScreen implements ZScreen.MouseButtonPressed {
        final ScreenEvent.MouseButtonPressed e;

        public MouseButtonPressed(ScreenEvent.MouseButtonPressed e) {
            super(e);
            this.e = e;
        }

        @Override
        public int getButton() {
            return e.getButton();
        }

        @Override
        public double getMouseX() {
            return e.getMouseX();
        }

        @Override
        public double getMouseY() {
            return e.getMouseY();
        }

        public static class Pre extends ForgeZScreen.MouseButtonPressed implements ZScreen.MouseButtonPressed.Pre {
            public Pre(ScreenEvent.MouseButtonPressed.Pre e) {
                super(e);
            }
            
            @Override
            public boolean isCanceled() {
                return e.isCanceled();
            }

            @Override
            public void setCanceled(boolean cancel) {
                e.setCanceled(cancel);
            }
        }

        public static class Post extends ForgeZScreen.MouseButtonPressed implements ZScreen.MouseButtonPressed.Post {
            public Post(ScreenEvent.MouseButtonPressed.Post e) {
                super(e);
            }
        }
    }

    public static class MouseScrolled extends ForgeZScreen implements ZScreen.MouseScrolled {
        private final ScreenEvent.MouseScrolled e;

        public MouseScrolled(ScreenEvent.MouseScrolled e) {
            super(e);
            this.e = e;
        }

        @Override
        public double getScrollDelta() {
            return e.getScrollDelta();
        }

        @Override
        public boolean isCanceled() {
            return e.isCanceled();
        }

        @Override
        public void setCanceled(boolean cancel) {
            e.setCanceled(cancel);
        }

        public static class Pre extends ForgeZScreen.MouseScrolled implements ZScreen.MouseScrolled.Pre {
            public Pre(ScreenEvent.MouseScrolled.Pre e) {
                super(e);
            }
        }

        public static class Post extends ForgeZScreen.MouseScrolled implements ZScreen.MouseScrolled.Post {
            public Post(ScreenEvent.MouseScrolled.Post e) {
                super(e);
            }
        }
    }

    public static class KeyPressed extends ForgeZScreen implements ZScreen.KeyPressed {
        private final ScreenEvent.KeyPressed e;

        public KeyPressed(ScreenEvent.KeyPressed e) {
            super(e);
            this.e = e;
        }

        @Override
        public int getKeyCode() {
            return e.getKeyCode();
        }

        @Override
        public int getScanCode() {
            return e.getScanCode();
        }

        @Override
        public int getModifiers() {
            return e.getModifiers();
        }

        @Override
        public boolean isCanceled() {
            return e.isCanceled();
        }

        @Override
        public void setCanceled(boolean cancel) {
            e.setCanceled(cancel);
        }

        public static class Pre extends ForgeZScreen.KeyPressed implements ZScreen.KeyPressed.Pre {
            public Pre(ScreenEvent.KeyPressed.Pre e) {
                super(e);
            }
        }

        public static class Post extends ForgeZScreen.KeyPressed implements ZScreen.KeyPressed.Post {
            public Post(ScreenEvent.KeyPressed.Post e) {
                super(e);
            }
        }
    }

    public static class CharacterTyped extends ForgeZScreen implements ZScreen.CharacterTyped {
        private final ScreenEvent.CharacterTyped e;

        public CharacterTyped(ScreenEvent.CharacterTyped e) {
            super(e);
            this.e = e;
        }

        @Override
        public char getCodePoint() {
            return e.getCodePoint();
        }

        @Override
        public int getModifiers() {
            return e.getModifiers();
        }

        @Override
        public boolean isCanceled() {
            return e.isCanceled();
        }

        @Override
        public void setCanceled(boolean cancel) {
            e.setCanceled(true);
        }

        public static class Pre extends ForgeZScreen.CharacterTyped implements ZScreen.CharacterTyped.Pre {
            public Pre(ScreenEvent.CharacterTyped.Pre e) {
                super(e);
            }
        }

        public static class Post extends ForgeZScreen.CharacterTyped implements ZScreen.CharacterTyped.Post {
            public Post(ScreenEvent.CharacterTyped.Post e) {
                super(e);
            }
        }
    }

    public static class Opening extends ForgeZScreen implements ZScreen.Opening {
        private final ScreenEvent.Opening e;

        public Opening(ScreenEvent.Opening e) {
            super(e);
            this.e = e;
        }

        @Override
        public Screen getCurrentScreen() {
            return e.getCurrentScreen();
        }

        @Override
        public Screen getNewScreen() {
            return e.getNewScreen();
        }

        @Override
        public void setNewScreen(Screen newScreen) {
            e.setNewScreen(newScreen);
        }

        @Override
        public boolean isCanceled() {
            return e.isCanceled();
        }

        @Override
        public void setCanceled(boolean cancel) {
            e.setCanceled(true);
        }
    }
}
